package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````$",```````!``````````.BA````
M````!0```$``.``*`$``&P`:``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````'*@`````````````````````````````'0````````````````````!
M``````````$````%````````````````````````````````````F)8`````
M``"8E@`````````0`````````0````8```!XFP```````'BK````````>*L`
M``````#8!``````````%`````````!`````````"````!@```)";````````
MD*L```````"0JP```````#`"````````,`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```"XCP```````+B/````````N(\```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````>)L```````!X
MJP```````'BK````````B`0```````"(!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!`````!````1TY5
M```````$````#P`````````$````%`````,```!'3E4`Y"I%"4V:KA?A&3P.
M5.MS0PBQD_=A````90``````````````40````4```````````````8`````
M```````````````[`````````!`````B````7@`````````O````20```$H`
M```\````60```&(````N````*P``````````````%@```$(````P````````
M``````!+````5````#H`````````50```&0````I````)P````<`````````
M#P`````````Y````6@```$@```!$`````````#8```!<````-0```"T````9
M``````````````!2````10```#@```!!````%````````````````````#X`
M```E````````````````````+````!(`````````"P```&,````;````````
M````````````&````#<````]````3``````````S`````````#\`````````
M`````%L`````````30````````!`````70```$8```!#````)@````T`````
M`````````````````````````````````````````````````````P``````
M````````````````````````````````````````````````````````````
M`&````!.```````````````.````&@````0`````````'@````````!0````
M```````````(`````````!\``````````````%\`````````*@``````````
M````6``````````1`````````&$````H````5@``````````````1P```#$`
M````````(0`````````C````(````!P````,``````````H```!3````````
M`!T`````````````````````````````````````````%0``````````````
M`````!<``````````````#(````D```````````````)````````````````
M``````````````!/````-``````````3`````@````````!7`````````!$`
M``!'````!`````@````@D!`!!4`$Q"@"`02`A@2$@HD``@D@!`B(@!!!N@`"
MB`````!'````2@```$T```!.````5@```%<```!9````6P```%P```!=````
M7P```&$```!B````9```````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA
M_^0.V7%8'.)'Q@&R`8MOK$OCP$+ZUX?"Y3\LNN.2?/JA;&"93\.;:PE#UF:O
MS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_J9R;X*<"
M"FL:GE"CX/M)```````````````````````````````````````````#``T`
MD"$``````````````````.<"```1`````````````````````````*4"```2
M`````````````````````````'T!```2`````````````````````````,4`
M```2``````````````````````````P"```2````````````````````````
M`(P"```2`````````````````````````,D!```2````````````````````
M`````,T````2`````````````````````````(4"```2````````````````
M``````````$!```2`````````````````````````$@"```2````````````
M`````````````-8!```2`````````````````````````+T````1````````
M`````````````````/(````2`````````````````````````+`!```2````
M`````````````````````-<"```2`````````````````````````/P!```2
M`````````````````````````)<````2`````````````````````````*$!
M```2`````````````````````````"D!```2````````````````````````
M`!D!```2`````````````````````````%@````2````````````````````
M``````$````@`````````````````````````'L````2````````````````
M`````````+T"```2`````````````````````````!T````@````````````
M`````````````.L````2`````````````````````````"`!```2````````
M`````````````````*\"```2`````````````````````````),!```2````
M`````````````````````+L````1`````````````````````````(0````6
M`````````````````````````%L!```2`````````````````````````"\!
M```2`````````````````````````(0!```2````````````````````````
M`-0````2`````````````````````````%L"```2````````````````````
M`````,(!```2`````````````````````````$H!```2````````````````
M`````````,@"```2`````````````````````````+4!```2````````````
M`````````````*P````2`````````````````````````*H"```2````````
M`````````````````&\!```2`````````````````````````-`!```2````
M`````````````````````)<"```2`````````````````````````'8!```2
M`````````````````````````*4````2`````````````````````````)H!
M```1`````````````````````````"T"```2````````````````````````
M`(L!```2`````````````````````````.H````2````````````````````
M`````$D````B`````````````````````````!@"```2````````````````
M`````````.(````2`````````````````````````+T!```2````````````
M`````````````.`"```2`````````````````````````'D"```2````````
M`````````````````.<!```2`````````````````````````*H#```2````
M`````````````````````&P"```1``````````````````````````L!```2
M`````````````````````````#\!```2`````````````````````````#D"
M```2`````````````````````````#<````2````````````````````````
M`/D````2`````````````````````````&(!```2````````````````````
M`````&H````2`````````````````````````/4!```2````````````````
M`````````+,#```2``T`HDH```````"B`````````$4$```2``T`!D0`````
M``#P!````````$0````2``T`D"$```````"``0```````"H#```2``T`=#L`
M```````"`````````$@#```2``T`]D@```````"L`0```````&L$```2``T`
M=CL```````"@`0```````"L$```0`!<`4+```````````````````#L#```2
M``T`%CT````````B`````````%X#```2``T`ED$```````!0`````````,L#
M```1``X`0$X````````$``````````@$```2``T`F$L```````#V````````
M`",$```2``T`BCH````````H`````````$`$```0`!<`>+``````````````
M`````%D$```2``T`2D,```````"\`````````(($```2``T`YD$```````!(
M`````````-H#```0`!8``+```````````````````((#```2``T`.#T`````
M``#>`````````/8#```0`/'_`+@``````````````````%($```0`!8`4+``
M`````````````````'@$```1`!8`2+`````````(`````````!,$```0`!8`
M4+```````````````````.`#```2``T`$",````````B`````````.<#```0
M`!8``+```````````````````#<$```2``T`1$L```````!4`````````-P#
M```@`!8``+```````````````````+\#```0`!<`>+``````````````````
M`)@#```2``T`-$,````````6`````````&P#```2``T`LCH```````#"````
M`````(X#```2``T`CDP```````"B`0```````(H$```2``T`%CX```````"`
M`P````````!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA
M;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`')E861L
M:6YK`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7W-V7W-E='!V`&UE;6-H<@!0
M97)L7W-V7W-E='!V;@!?7V5N=FER;VX`<W1R;F-M<`!S=')L96X`7U]M96UM
M;W9E7V-H:P!R96%L;&]C`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I
M<C8T`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`&)O;W1?
M1'EN84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`9V5T<&ED
M`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``<W1R
M<F-H<@!M96UC<'D`<W1D97)R`%]?=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV
M-`!R96%D`&UE;6-M<`!G971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?
M7V9P<FEN=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?
M9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?
M9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P
M97)L7V-O;G-T<G5C=`!P97)L7W)U;@!M96US970`7U]S=&%C:U]C:&M?9W5A
M<F0`;&EB<&5R;"YS;P!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T
M9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R
M;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S
M960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT
M97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<`
M+W5S<B]L:6(O<&5R;#4O-2XT,BXP+W)I<V-V-C0M;&EN=7@M=&AR96%D+6UU
M;'1I+T-/4D4```````(``0`#``,``0`!``,``P`#``,``0`#``,``P`#``$`
M`0`!``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!
M``$``P`!``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$`
M`P`!``$`!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``P`$`P``$````$``
M``"TD98&```%`)<$```0````LY&6!@``!`"B!```$````(>1E@8```,`K00`
M```````!``$`#@,``!``````````AY&6!@```@"M!````````'BK````````
M`P`````````R(P```````("K`````````P````````#$(P```````(BK````
M`````P````````",(P```````/BO`````````P````````"0(0````````"P
M`````````P``````````L````````!BP`````````P````````"@3P``````
M`""P`````````P````````!XCP```````"BP`````````P````````"`CP``
M`````#"P`````````P````````"(CP```````#BP`````````P````````"0
MCP```````$BP`````````P`````````(4@```````*"O`````````@````(`
M`````````````*BO`````````@````P``````````````+"O`````````@``
M``X``````````````+BO`````````@```!@``````````````,"O````````
M`@```!L``````````````,BO````````"P```"$``````````````-"O````
M`````@```",``````````````-BO`````````@```"8``````````````."O
M`````````@```#(``````````````.BO`````````@```#8`````````````
M`/"O`````````@```#X``````````````-"M````````!0````,`````````
M`````-BM````````!0````0``````````````."M````````!0````4`````
M`````````.BM````````!0````8``````````````/"M````````!0````<`
M`````````````/BM````````!0````@```````````````"N````````!0``
M``D```````````````BN````````!0````H``````````````!"N````````
M!0````L``````````````!BN````````!0````T``````````````""N````
M````!0````\``````````````"BN````````!0```!```````````````#"N
M````````!0```!$``````````````#BN````````!0```!(`````````````
M`$"N````````!0```!,``````````````$BN````````!0```!0`````````
M`````%"N````````!0```!4``````````````%BN````````!0```!8`````
M`````````&"N````````!0```!<``````````````&BN````````!0```!D`
M`````````````'"N````````!0```!H``````````````'BN````````!0``
M`!P``````````````("N````````!0```!T``````````````(BN````````
M!0```!X``````````````)"N````````!0```!\``````````````)BN````
M````!0```"(``````````````*"N````````!0```"0``````````````*BN
M````````!0```"4``````````````+"N````````!0```"<`````````````
M`+BN````````!0```"@``````````````,"N````````!0```"D`````````
M`````,BN````````!0```"H``````````````-"N````````!0```"L`````
M`````````-BN````````!0```"P``````````````."N````````!0```"T`
M`````````````.BN````````!0```"X``````````````/"N````````!0``
M`"\``````````````/BN````````!0```#````````````````"O````````
M!0```#$```````````````BO````````!0```#,``````````````!"O````
M````!0```#0``````````````!BO````````!0```#4``````````````""O
M````````!0```#<``````````````"BO````````!0```#@`````````````
M`#"O````````!0```#D``````````````#BO````````!0```#H`````````
M`````$"O````````!0```#L``````````````$BO````````!0```#P`````
M`````````%"O````````!0```#T``````````````%BO````````!0```#\`
M`````````````&"O````````!0```$```````````````&BO````````!0``
M`$$``````````````'"O````````!0```$(``````````````'BO````````
M!0```$,``````````````("O````````!0```$0``````````````(BO````
M````!0```$4``````````````)"O````````!0```$8``````````````)>3
M```S`\-!`[X#_A,#0_V3@@/^$U,3`(.R@@!G``X`%YX```,^#OUG`PX`$P``
M`!>>```#/H[\9P,.`!,````7G@```SX._&<##@`3````%YX```,^COMG`PX`
M$P```!>>```#/@[[9P,.`!,````7G@```SZ.^F<##@`3````%YX```,^#OIG
M`PX`$P```!>>```#/H[Y9P,.`!,````7G@```SX.^6<##@`3````%YX```,^
MCOAG`PX`$P```!>>```#/@[X9P,.`!,````7G@```SZ.]V<##@`3````%YX`
M``,^#O=G`PX`$P```!>>```#/H[V9P,.`!,````7G@```SX.]F<##@`3````
M%YX```,^CO5G`PX`$P```!>>```#/@[U9P,.`!,````7G@```SZ.]&<##@`3
M````%YX```,^#O1G`PX`$P```!>>```#/H[S9P,.`!,````7G@```SX.\V<#
M#@`3````%YX```,^CO)G`PX`$P```!>>```#/@[R9P,.`!,````7G@```SZ.
M\6<##@`3````%YX```,^#O%G`PX`$P```!>>```#/H[P9P,.`!,````7G@``
M`SX.\&<##@`3````%YX```,^CN]G`PX`$P```!>>```#/@[O9P,.`!,````7
MG@```SZ.[F<##@`3````%YX```,^#NYG`PX`$P```!>>```#/H[M9P,.`!,`
M```7G@```SX.[6<##@`3````%YX```,^CNQG`PX`$P```!>>```#/@[L9P,.
M`!,````7G@```SZ.ZV<##@`3````%YX```,^#NMG`PX`$P```!>>```#/H[J
M9P,.`!,````7G@```SX.ZF<##@`3````%YX```,^CNEG`PX`$P```!>>```#
M/@[I9P,.`!,````7G@```SZ.Z&<##@`3````%YX```,^#NAG`PX`$P```!>>
M```#/H[G9P,.`!,````7G@```SX.YV<##@`3````%YX```,^CN9G`PX`$P``
M`!>>```#/@[F9P,.`!,````7G@```SZ.Y6<##@`3````%YX```,^#N5G`PX`
M$P```!>>```#/H[D9P,.`!,````7G@```SX.Y&<##@`3````%YX```,^CN-G
M`PX`$P```!>>```#/@[C9P,.`!,````7G@```SZ.XF<##@`3````%YX```,^
M#N)G`PX`$P```!>>```#/H[A9P,.`!,````7G@```SX.X6<##@`3````77&&
MY";\HN!*^)>4``"#M&3@G&`^](%'+N@RY"K.,``,"&@([_#?]Q>6```#-@;?
MLH47E0```S5EX>\@<$:7EP``@[<GXH/'!P#ASY>7``"#M\?>%Y0``!,$1.>2
MEYAC<D:#1Z=+&P5&``X%D^<W`",-]TH-)C+@[_"?[<)E%Y<```,WI^-R2(.X
M!0"JAI<W``"3AR?^%S4``!,%)?V<[A3D([`6`8CFF.J%1P)F8]('#:$%#2@1
M1XAADQ<W`+:7!2>(XZ$%XQD'_PX'"&PVER,P!P"7%0``DX7%?`%'[_`_O37%
M"&SO\+_<3!`JB1<U```3!27++N#O$,`]@F4AS0AL[_#_MN_PO\TB=YQ@N8\!
M1ZWGIF`&9.)T2H5">6%A@H#O\/_(%Y0``!,$)-H([#G![_#_T9>7``"#MR?0
M,X='`!AC$P?W?Z,+!Q(!OPAL[_`?OD&_"&@!Q>\@@'M-MQ<U```3!86\[Q#`
M-@CH2=GMMQ%'F;\%1>_PG[KO\%_F[P`@`JJ'%Y4```,U)<Z"93``$W$!_X%&
M`4<*B._P7^$"D)>1``"3@>%,@H```!>5```3!271EY<``).'I]!CB*<`EY<`
M`(.W9\:1PX*'@H`7E0``$P4%SY>5``"3A87.B8V3US5`_9&^E86%F<67EP``
M@[<GQ)'#@H>"@)>7``"#QT?,G>=!$0;DEY<``(.WY\21QQ>5```#-<7%@I?O
M\!_YHF"%1Q>7```C#??(00&"@(*`<;\3`0'1(S1Q*R,T$2XC,($N(SR1+",X
M(2TC-#$M(S!!+2,\42LC.&$K(S"!*R,\D2F7FP``@[NKNC0`06^3"(4#DP*%
M!X.W"P`C-/$H@4<VB!,/#_"W#_\``[8(`*$(00B3508"$W?V#Y,>A@"35X8"
M$UZ&`!/S]0^34X8#8@>S_OX!L_?G`3-GUP$S?NX!8@.B!;/G=P`S9\<!&U:&
M`;/U]0&SYV<`48_-CR,XZ/XC//C^XY,2^T9TYG.*8F)K@GHB>L)Y8GF&9**,
M'HX6AUJ,5H/2B$Z(RH6FCI./!B`1H+*.L&*<8CJ/H0:QC[/'AP&SQY<!$Y<7
M`/V#78\"%P&3N/X:C/*,1H-ZCL*(+HCVA>.8]OT#,P4`$&D,;:)F`SB%`(,X
M!0*WAX):DX>7F1-7LP$3'%,`OI8S;.P`,T>V`,:6,W<'`2V/-IPZG!,>Z`$3
M5R@`,V[N`!,?XP$35R,`,V_O``(<$UP,`K-&[@'";C,'^P"S]H8!,I>SQL8!
MNI8S1\8!OIXS=V<`KIXQC[Z:\IIVEQ->O`&3'EP`,^[.`7*7DQ\'`I/?#P(3
MWK\!$Y=?`#-GQP$3'NP!$UPL`#-NC@&ZEH(6,T?/`8&2LP[Z`#-W]P'ZGA/:
MM@$S1^<!$Y]6`#-O3P%6EQ.:[P&3WR\`,VKZ`7J7`A<S3TX!`9,S?]\`DQ]7
M`#-/SP&36K<!=I^S[E\!DY_F`8F"L^_?`':?`A^S3OH!$U\/`K.&^0"S_NX`
M\I:36;\!$QY?`+/.3@&VGK-F/@$3'N<!"8,S;NX`MIXSQ\\!@AZ3W@X"LP;Y
M`#-WYP'2EC-']P$3F5X`D]F^`3:7,VDY`9,6[P$37R\`L^;F`4J7$Q\'`C-'
MW@"^E#-WUP$37P\"II\S1\<!DU2_`7Z7DQ]?`+/OGP`3F>X!IF23WBX`LV[9
M`7Z7DQ\'`C/'U@&^E#-WYP&3WP\")IXUCY/4OP%REQ.>7P`S;IX`1FEREQ,>
M[P$37R\`,V[N`9,4!P(SQ\X!,P_Y`#-W]P&!D/J6,T?7`1/?M`$VEY.65`"S
MYN8!-I=F;Y.6[P&3WR\`L^;V`1,9!P(S1]X`/I]ECQ-9"0+ZGC-'QP$37[D!
M=I>3'ED`L^[N`7:7!G^3GN0!B8"S[IX`DQ\'`C/'U@$^GS-W)P&3WP\">IXU
MCQ/?OP%REQ.>7P`S;NX!<I<3'^D!)GX362D`,V\O`9,4!P(SQ^X!@9`^GC-W
M]P'REC-'UP$3GE0`$]FT`3:7LV8N`1.>[P&3WR\`,V[^`3:7DQ8'`C-'SP&!
MDCZ498^BGI.?5@`3U+8!,T?G`7:7L^Z/`).?Y`&)@+/OGP!VEQ,4!P(S1_X!
MLX[S`'6/`9#ZGC-'QP$37[0!=I>3'E0`L^[N`1.?Y@&)@C-OWP!VEY,6!P(S
MQ^\!OI)ACX&2%IXS1_<!D]ZV`7*7$YY6`#-NW@&J8I,>Y`$)@+/NC@!REQ,>
M!P(S1]\!OI)UCQ->#@*6GS-'YP&34KX!?I>3'UX`L^]?`'Z7RF*3G^8!B8*S
M[]\`DQ8'`C/'_@&^DC-WQP&!DA:?,T?7`9/2M@%ZEQ.?5@`S;U\`>I?J8A,?
M[@$37BX`,V_/`3/.[P&^DC-^W@`"%P&3EIXS3OX!DU*W`7:>DQY7`+/N7@!V
MGHI^DY3F`8F"U8RSAOX`LT>?`!,4#@+YCP&0_I:SQ^<!MI>37K0!DQ94`*I_
ML^;6`;..UP"3$^<!M_?9;@F#DX<7NK/CXP"SQG0`,X?_`).2#@*3T@(">I>S
MQL8!NI83WK(!$Y=2`#-GQP&ZEDIW$UXD`),?Y`&S[\\!,\[S`1.4!@(^EP&0
M,T[>`2:7DUZT`7*7$QY4`#-NW@%REVI^$Y_B`9/2(@`S;U\`L\+O`3Z>DQX'
M`I/>#@*SPM(`LP9^`):6$YY>`)/2O@$S;EX`\I8.;I,2Y`$)@+/B@@"3DP8"
MD],#`C-$7P`^GCF,,P?^`9/?LP$3GE,`,V[^`2*7<I<N;A/4+@"3G^X!L^^/
M`),>!P*3W@X",\3R`3Z>-8RS!NX!$]^^`1.>7@`S;NX!HI;REDYN$]0C`!.?
MXP$S;X\`DY,&`I/3`P(SQ.\!/IXYC#,'7@"3TK,!$YY3`#-N7@`BEW*7;FX3
MU"X`DY+N`;/B@@"3'@<"D]X.`C-$7P`^GC6,LP;^`9/?O@$3GEX`,V[^`:*6
M\I8.?A/4(P"3G^,!L^^/`).3!@*3TP,",\3R`3Z>.8PS!^X!$]^S`1.>4P`S
M;NX!(I=RERY^$]0N`!.?[@$S;X\`DQX'`I/>#@(SQ.\!/IXUC+,&7@"3TKX!
M$YY>`#-N7@"BEO*63GX3U",`DY+C`;/B@@"3DP8"D],#`C-$7P`^GCF,,P?^
M`9/?LP$3GE,`,V[^`2*7<I=N?A/4+@"3G^X!L^^/`),>!P*3W@X",\3R`3Z>
M-8RS!NX!$]^^`1.>7@`S;NX!HI;REA)N$]0C`!.?XP$S;X\`DY,&`I/3`P(S
MQ.\!/IXYC#,'7@"3TK,!$YY3`#-N7@`BEW*7,FX3U"X`DY+N`;/B@@"3'@<"
MD]X.`C-$7P`^GC6,LP;^`9/?O@$3GEX`,V[^`:*6\I92;A/4(P"3G^,!L^^/
M`).3!@*3TP,",\3R`3Z>.8PS!^X!$]^S`1.>4P`S;NX!(I=REW)N$]0N`!.?
M[@$S;X\`DQX'`I/>#@(SQ.\!/IXUC+,&7@"3TKX!$YY>`#-N7@"BEO*6$GX3
MU",`DY+C`;/B@@"3DP8"D],#`C-$7P`^GCF,,P?^`9/?LP$3GE,`,V[^`2*7
M<I<R?A/4+@"3G^X!L^^/`),>!P*3W@X",\3R`3Z>-8RS!NX!$]^^`1.>7@`S
M;NX!HI;REE)^$]0C`!.?XP$S;X\`DY,&`I/3`P(SQ.\!/IXYC#,'7@"3TK,!
M$YY3`#-N7@`BEW*7<GX3U"X`DY+N`;/B@@`S1%\`DQX'`CZ>D]X.`J&.?IXV
MGI/?O@&3EEX`L^;V`3:>EF:3G^,!D],C`+/O?P"SP_(!MI<"'A->#@(SQ^,`
M^I>35KX!NI<3%UX`58^ZEQ.?[@&3WBX`,V_?`;9FDYX'`K?WQB.*!Y.'Q\TS
MY^\!OI:6EC-WQP&S\N\!D]X.`C-G5P#68Y/2O@$VEY.67@"SYE8`DQ+N`1->
M+@"SXL(!-I<SCO,`DQ8'`C-G7P!^GC-WUP&S?U\`@9(S9_<!]F.3W[8!<I<3
MGE8`,V[^`9.?[@&3WBX`L^_?`7*7LX[S`!,>!P(SY_(!^IYUCS/_\@$37@X"
M,V?G`7:7$U^^`9,>7@"S[NX!=I>6?A.?Y@&)@C-OWP"^GI,6!P(SY^\!EIXS
M=\<!L_+O`8&2,V=7`':7D]*V`9.>5@"S[EX`MG)VEY,>[@$37BX`L^[.`;Z2
M$QX'`C-GWP&6GW6/LW+?`1->#@(S9U<`?I>34KX!DQ]>`+/O7P#6<GZ7DY_F
M`8F"L^_?`+Z2DQ8'`C/G_@$6GS-WQP&S\OX!@9(S9U<`>I>3TK8!$Y]6`#-O
M7P#V<GJ7$Q_N`1->+@`S;\\!OI(3'@<",^?O`9:>=8^S\N\!$UX.`C-G5P!V
MEY-2O@&3'EX`L^Y>`)IB=I>3GN8!B8*S[MX`OI*3%@<",V??`9:?,W?'`;-R
MWP&!DC-G5P!^EY/2M@&3GU8`L^]?`+IB?I>3'^X!$UXN`+/OSP&^DA,>!P(S
MY_X!%I]UC[/R_@$37@X",V=7`'J7DU*^`1,?7@`S;U\`VF)ZEQ.?Y@&)@C-O
MWP"^DI,6!P(SY^\!EIXS=\<!L_+O`8&2,V=7`':7D]*V`9.>5@"S[EX`^F)V
MEY,>[@$37BX`L^[.`;Z2$QX'`C-GWP&6GW6/LW+?`1->#@(S9U<`?I>34KX!
MDQ]>`+/O7P":<GZ7DY_F`8F"L^_?`+Z2DQ8'`C/G_@$6GS-WQP&S\OX!@9(S
M9U<`>I>3TK8!$Y]6`#-O7P"Z<GJ7$Q_N`1->+@`S;\\!OI(3'@<",^?O`9:>
M=8^S\N\!$UX.`C-G5P!VEY-2O@&3'EX`L^Y>`-IR=I>3GN8!B8*S[MX`OI*3
M%@<",V??`9:?,W?'`;-RWP&!DC-G5P!^EY/2M@&3GU8`L^]?`/IR?I>3'^X!
M$UXN`+/OSP&^DA,>!P(SY_X!%I]UC[/R_@$37@X",V=7`'J7DU*^`1,?7@`S
M;U\`GF)ZEQ.?Y@&)@C-OWP"^DI,6!P(SY^\!EIXS=\<!L_+O`8&2,V=7`':7
MD]*V`9.>5@"S[EX`OF)VEY,>[@$37BX`L^[.`;Z2$QX'`C-GWP&6GW6/LW+?
M`1->#@(S9U<`?I>34KX!DQ]>`+/O7P#>8GZ7DY_F`8F"L^_?`+Z2DQ8'`C/G
M_@$6GS-WQP&S\OX!@9(S9U<`>I>3TK8!$Y]6`#-O7P#^8GJ7$Q_N`1->+@`S
M;\\!,^[O`;Z2EIXS?MX`L_+O`0(7`9,S;EX`=IZ34K<!DQY7`+/N7@!VGIY^
M$Y3F`8F"58RSAOX`LV>/`+-^CP"3$@X"^8^3T@("_I:SY]<!MI>3WK(!DY92
M`+/FU@&^EKYSM[>8,I,4YP&*!PF#DX=G'=F,LTZ4`#.'\P"3GP8"D]\/`GJ7
ML\[.`;J>$]Z_`1.77P!>?S-GQP&ZGI.3X@$3UR(`L^/C`#/.=``S!_\`DY(.
M`I/2`@(BES-.W@`ZGI/6L@$3EU(`58\ZGGYWD]8O`!.4[P%5C+/&@P"3'PX"
M/I>3WP\"L\;6`2:7D]Z_`3:7DY9?`+/FU@$VEX,V`2"3GN(!D](B`+/N7@"S
M0M0!$Q\'`KZ6$U\/`C/.P@&>EI-2OP'REA,>7P`S;EX`\I8#/H$@DY/O`9/?
M+P"SX_,!L\]^`#Z>DY(&`I/2`@*SS^\`,P>.`'Z7$YY2`)/?L@$S;OX!<I<#
M/@$A$U0O`),?[P&S[X\`$Q\'`A-?#P(SQ/,!/IXUC+,&W@&37K\!$QY?`#-N
MW@&BEO*6`SZ!(1/4(@"3GN(!L^Z.`).2!@*3T@(",\3?`3Z>.8PS!WX`D].R
M`1.>4@`S;GX`(I=REP,^`2(35"\`DQ/O`;/C@P`3'P<"$U\/`C/$?@`^GC6,
MLP;^`9-?OP$3'E\`,V[^`:*6\I8#/H$B$]0B`).?X@&S[X\`DY(&`I/2`@(S
MQ/,!/IXYC#,'W@&3WK(!$YY2`#-NW@$BEW*7`SX!(Q-4+P"3'N\!L^Z.`!,?
M!P(37P\",\3?`3Z>-8RS!GX`DU._`1,>7P`S;GX`HI;RE@,^@2,3U"(`DY/B
M`;/C@P"3D@8"D]("`C/$?@`^GCF,,P?^`9/?L@$3GE(`,V[^`2*7<I<#/@$D
M$U0O`),?[P&S[X\`$Q\'`A-?#P(SQ/,!/IXUC+,&W@&37K\!$QY?`#-NW@&B
MEO*6`SZ!)!/4(@"3GN(!L^Z.`).2!@*3T@(",\3?`3Z>.8PS!WX`D].R`1.>
M4@`S;GX`(I=REP,^`2435"\`DQ/O`;/C@P`3'P<"$U\/`C/$?@`^GC6,LP;^
M`9-?OP$3'E\`,V[^`:*6\I8#/H$E$]0B`).?X@&S[X\`DY(&`I/2`@(SQ/,!
M/IXYC#,'W@&3WK(!$YY2`#-NW@$BEW*7`SX!)A-4+P"3'N\!L^Z.`!,?!P(3
M7P\",\3?`3Z>-8RS!GX`DU._`1,>7P`S;GX`HI;RE@,^@2:3TR(`$Y3B`3-D
M=`"3D@8"D]("`CZ>L\..`+/#XP`S!_X!D]^R`1.>4@`S;OX!'I=REP,^`2>3
M'^\!$U\O`+/O[P&3$P<"D],#`CZ>,T_T`3-/WP"S!MX!D]ZS`1.>4P#ZEC-N
MW@&SCL8!@S:!)Q/>(@`3G^(!,V_/`9.2#@*3T@("OI:SQ.\!N8P3GE(`,X>&
M`)/6L@$S;MX`@S8!*":7<I<3GN,!D],C`#-N?@"VEP(7`9.:E[-&SP&SQM8!
M$Q-7`)->MP'^E[:7,V/3`9.6X@&3TB(`L^96`)J7.ICZF#.'Q@#RE8(7@9,3
ME@@"DQ8(`H(5`A>!D@&2@9$!DQSA%.40\0SM@S:!*(.W"P"UCX%&&.F5ZX,P
M@2X#-`$N@S2!+0,Y`2V#.8$L`SH!+(,Z@2L#.P$K@SN!*@,\`2J#/($I$P$!
M+X*`[^`?O5UQA6*&Y*+@)OQ*^$[T,P%10",P`4`%9QP((0<^EP5F%X0```,T
MQ)TJB:Z)?18L"!<E```3!46''&`<XX%'[^#_E)L&!0!C6M``&X?V_[,'X0"#
MQX<!G>\-[Y>'``"#MZ><3H;*A9*7B&/OX#^-A6<8"*$'NI>88QQ@N8\!1YWO
MA6(6D:9@!F3B=$)YHGEA88*`NH8H"#:&DP7P`C;D[^#_H47=EX<``(.W!YBB
M9C`(DI>(8\J%[^!_FE6_[^`?L3EQ!OPB^%;DEX<``(.W1Y2#N@<`8X,*"$KP
M@T<%`(''DX<W_*'K`4D#M`H`+<@F]$[L4NA:X*J)+HO6A!,*T`-*ALZ%(H7O
MX&_WLP<D`0GE@\<'`&.+1P.`9*$$=?"B=`)YXFE":@)KXG`BA4)THFHA88*`
M*HF#1QD`!0D3AS?\D<-U^SL)J4!%M[.$5$&-A`4)(R";`$J4V;<!1/&W`GGA
MMQUQHNBFY,K@ANQ._%+X%XD```,YR8@#QP4`@S<)`#[T@4>3!]`#+H2JA&,4
M]P`3A!4`(H7OX&_RJHE,$":%[_`?\BJ*><WOX$_Q8WTU"Q)6%XH```,ZJH4.
M!H/'!`!CAP<4DX<W_&.#!Q0FA8-'%0`%!8''DX<W_/7[!9V#-PH`B0E.E3+D
MLXG'`._@#^XCL*D`.<F#-PH`(F8#QP0`LI><8Y,&-_P;!@<`(X#G`(W"!<(3
MA10`(:"3AC;\D<H#1P4`!06%!R.`YP";!@<`;?<3!]`#(X#G`(4'`T<$``4$
MA0>CC^?^=?LB=X,W"0"YCP%'Z>/F8$9DIF0&:>)Y0GHE88*``T<$``4$!0JC
M#^K^8=\#1P0`!00%"J,/ZOY]\^&W%WH```,ZBG@#.`H`@S<(`+W/0H>!1Q1G
M(0<^AH4GY?Z;!C8`C@87AP```R>G@"GC!4<VA3[H0NP7=@``(RSF?C;D[^!O
MX$'1PF>B9N)E$Y8W`#+D*NSOX"_S8F?"9R)F(S#J`(4GC@<^ER,P!P#IM;:%
M0H4^Y._@/X$C,*H`*H<YT:)G$Y8W`/&_`47YM<%&6;_OX'^+<7$B\2;M!O47
M=````S2D;2P`'&`^Y8%'JH3OX(_[#>'B1[UF$6?UCV.%YP`I9V.:YP`FA8E%
M[^#/VA,U%0`1H`%%*F<<8+F/`4>1YZIP"G3J9$UA@H#OX-^%57%*^8;E%WD`
M``,Y*6B#-PD`/NV!1QG%HN&#1P4`*H2)[PYD:F>#-PD`N8\!1V.0!PZN8$IY
M:6&"@";][^#/_ZJ$1<TFA>_@+])5P0-'-0&3!S4!&P<G_9L&!P`9XX/&%P#M
MT@-'-0$;!R?]FP8'``'K`\<7`!L')_V;!@<`2</QTB*%3O4^X._@#\R"9ZJ)
M/H4^Y._@3\L[AJD`"28RA3+@[^!ORZ)G`F8BAY<6``"3AD9)B46JB>_@#_0L
M"$Z%[^"/U_U78PGU`*)7D483U\=`/8MC"=<"3H7OX._13H7OX(_A)H6J>>_@
M#\@E\2:%[^"/U2*%[^`OSPYDZG0=MX/&)P"UOTZ%[_"?[\F_HN$F_4[U[^!/
M]$$1(N`7=````S1$60;DEU8``).&)E:S!T0`B&,7=@```S9&6)<5``"3A<5`
M[^!/[!*4"&`"9*)@%Q<``!,'AWBZAH%'%Q8``!,&)NB7%0``DX5%0$$!;^"O
MU)=W``"#M^=3EU8``).&YE`7=@```S9F4Y*7B&.7%0``DX6E.V_@+^==<85B
MAN2BX";\2O@S`5%`(S`!0#,!44`C,`%`"6<<"&$'/I<7>0```SFI3(,W"0`<
MXX%'[^"ORH5GDX<'`C.$)P`%9BJ'EQ<``).'!SHBA04&EQ8``).&QCF)1>_@
M+^`BA2P(!6;OX(_!&P0%`(%'8T0$`IL&%``VA3;D[^`OM*J'&<FB9B*&+`@J
MX._@+^*"9SZ4(P`$``EG%`AA!S:7%&,#-PD`-8^!1A'KB6(6D:9@!F3B=$)Y
M/H5A88*`[^`/X#V_%7&%8H;MHNFFY<KA3OU2^5;U6O%>[3,!44`C,`%`!6<3
M!X<("I>7>@``@[I*0"J)+H07%0``$P4%,4P`@[<*`!SC@4?O\+^JJH23!?`"
M2H7OX*_%*<$7%0``$P7%+\J%[_`?LTJ%A6>3AX<(BI>88X.W"@"YCP%'8Y('
M$H5B%I'N8$YDKF0.:>IY2GJJ>@I[ZFLM88*`(H7OX"_$EQ4``).%92SOX&^?
M*H15U8-'!``%:KW#D<2BA2:%[^`/MRG!(H7OX(^BDP?U_Z*7JHN3!O`"8VCT
M`#&H(X`'`/T78P;T``/'!P#C"=?^(H7OX.^?JHM*A>_@;Y]>E0D%8V5%!9<5
M``"3A24F`47OX`^9*H0YT8-'!`#9_YG(@\<$`)N')_T;AP<`F>,#QQ0`<=M*
MA85+[^"/FUZ5"047%```$P0$(.-_1?N)12*'2HB7%P``DX?G(9<6``"3AN8A
M!68H`>_@K\,L`"@![^`OIU'YXD>A1A/7QT`]B^,4U_B%12@![^"OFC7]+`$7
M%0``$P6E'._P'Z`H`>_@3[3QM>_@[\5!$9,%\`(BX`;D*H3OX.^U&<$3!!4`
M(H4"9*)@00%OX,^Q>7&%8@;T(O`S`5%`(S`!0`5G'`@A!Q=T```#-"0E/I<<
M8!SC@4=)P8-'!0"USRKD[^"/CQ,&%0`%9V-NQPBB92KD*`COX$^@HF<JAY,&
M\`(3A??_.I5C:*<`$:@C``4`?15C!N4`@T<%`..)U_X\"#Z%DP7P`C[D[^`/
MK:)G#<5CZ*<$*`COX"^IA6<8"*$'NI>88QQ@N8\!1Z'CA6(6D:)P`G1%88*`
MA6<8"*$'NI>88QQ@N8\!1XWCA6(6D:)P`G07%0``$P5E"T5A;^#/I",`!0!%
MOP%%3;_OX.^U>7$B\";L2N@&])=T``"#M`08G&`^Y(%'0``7>0```SD)&**%
M%Q4``!,%90OO\#^"#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<5```3
M!>4([_"O_VG]%WD```,Y"12BA1<5```3!64([_`O_@W%$D>#-PD`#@>ZEYAG
MF.-MTYAKH0>8XVW_HH47%0``$P7E!>_PK_MI_1=Y```#.0D0HH47%0``$P7E
M!._P+_H-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%Q4``!,%90+O\*_W
M:?T7>0```SD)#**%%Q4``!,%Y0'O\"_V#<421X,W"0`.![J7F&>8XVW3F&NA
M!YCC;?^BA1<5```3!67_[_"O\VG]%WD```,Y"0BBA1<5```3!67^[_`O\@W%
M$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47%0``$P7E^^_PK^]I_1=Y```#
M.0D$HH47%0``$P5E^^_P+^X-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%
M%Q4``!,%Y?CO\*_K:?T7>0```SD)`**%%Q4``!,%Y>_O\"_J#<421X,W"0`.
M![J7F&>8XVW3F&NA!YCC;?^BA1<5```3!67M[_"OYVG]%WD```,Y"?RBA1<5
M```3!67T[_`OY@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47%0``$P7E
M\>_PK^-I_1=Y```#.0GXHH47%0``$P5E\>_P+^(-Q1)'@S<)``X'NI>89YCC
M;=.8:Z$'F.-M_Z*%%Q4``!,%Y>[O\*_?:?T7>0```SD)]**%%Q4``!,%9>[O
M\"_>#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<5```3!>7K[_"OVVG]
M%WD```,Y"?"BA1<5```3!>7@[_`OV@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8
MXVW_HH47%0``$P5EWN_PK]=I_:*%%Q4``!,%Y>?O\*_6`<FJA1<5```3!>7D
M[_#/WZ*%%Q4``!,%A>?O\,_4`<FJA1<5```3!07H[_#OW:*%%Q4``!,%)>CO
M\._2!<VJA1<5```3!:77[_`/W")GG&"YCP%'H>,"=*)PXF1":9<5``"3A<7G
M%Q4``!,%Q=M%86_PC]FBA1<5```3!<7D[_"/SFG5JH47%0``$P7%V^_PK]=M
MO^_0__T!$2+H!NP7=````S1$X$P`%Q4``!,%I=D<8#[D@4?O\`_+`<V#1P4`
M$X4'_1,U%0"3MQ<`78T3114`(F<<8+F/`4>)Y^)@0F0%88*`[]#_^!UQ!NP7
M<P```S-CWRJ.`S4#`!,#@0(N]#+X-OQRAKK@%WX```,^KMF^Y,+HQNR:AHE%
M@S<.`#[D@4<:X._0_\P3!?`/[]!_R%UQ06.&Y*+@)OQ*^$[T4O!6[%KH,P-A
M0(5B,P%10",P`4#C'&'^06<A!PJ7%WH```,Z:M2#-PH`'..!1PE&@46JBN_0
M']@3"?7_$U?Y0T&3LP?I`,(7P9.9CS,)^4!C1`D(_5D=2P%&RH56A>_0?]5C
M#34'068A!HJ%5H7OT'_A`25C"C4'8WRK!&$5,P2A`&-V)`"IH'T48V,D!"%&
MEW4``).%Q=,BA>_0O\YM]3,%)$!*E<%GH0>*EYAC@S<*`+F/`4>=[\%B%I&F
M8`9DXG1">:)Y`GKB:D)K86&"@,%W/IGC$OGX?57QMQ<5```3!87,[_!_[!<5
M```3!<7,[_"_Z^_0'^1!$0;D[]"?L>_07]P1P0AAHF!!`8*`.7$B^";T!OP7
M=````S3DQ*J$3`@7%0``$P4ERAQ@/NR!1^_PCZ\!Q8-'!0"-XV)G'&"YCP%'
MIH47%0``$P7EQZWK0G3B<*)T(6%O\"^W*N`FA4KP[]`_K`)H*HE"A4+D[]!_
MJS,&J0`)!C*%,N#OT)^K(F@"9B:'EQ<``).'9[&7%@``DX;FL8E%*HGOT+_3
M8F<<8+F/`4>%XT)TXG"B=,J%`GD7%0``$P4EP2%A;_#OL$KP[]`_U^_0_]:7
M=P``DX<GP`.XAP-)<0._!P&#OH<!`[X'`@.SAP*#N`<#IN[*ZL[FAO:B\F0(
M%WD```,YR;:JB1<6```3!J:]EQ8``).&IJ87%P``$P<GO9<7``"3AR>]0N&F
MA1<5```3!66E`S@)`$+F`4B"Z`+\^NSV\/+TFOC&_++@MN0Z]#[X[_#/G1'%
M@T<%`"J$8Y\'(-+B5OY:^E[V[]`?F^_0W\5C`048@SH%`&.-"A96A>_0OYH3
M%!4`!00BA>_0_YH#QPH`*HNBBRJ*!<^7%@``DX9FMB*&B45:A>_0'\.%"MZ&
M8_.+`**&LX>&0(D'8_/7`+:'`\<*`'D4%8P^E`D+<?>@"!<5```3!66I(:`(
M9"$$#<&FA>_PCY2JBFW9@T<%`/77[_!/N7W15H7OT/^Q*H0-X09DDPH!!`G,
M@T<$`&.`!PXBA>_P+[=AY:$*`[0*`&WT(H7OT%^0JHI2A>_0WX^[BJH`FXI*
M0%:%[]#_CY<7``"3AZ>6TH@BAU:&%Q@``!,(R*N7%@``DX;&JXE%*HOOT)^W
M6H63!0`<[]#_J/U78QCU`._07XX<045'8Y_G#"P!6H7OT%^M*H0!Z>I'D483
MU\=`/8MC`]<*EW<``(.WYZ"#M@D`B&-:AQ<6```3!F:KB47OT%^P`4HR9X,W
M"0"YCP%'8Y$'+K9P%G3R>E)[LGOV9%9IMFE2A19J=6&"@"*%[]!_HRJ$#?VA
M"@6_`40-OR)U(!`9R::%[_`O@P'%@T<%`)7C"&0A!'WU-47OT+^"M4LJBRJ*
M7H27&@``DXKJFQ,',`65O>_0'Y^JBF'=[]"/_Q,4%0`%!+FU"EKOT*_]XQRJ
M].I'8O(3!P`<D_?W'V.&YP02?(FW%W<```,WYY2#M@D`"&,7%@``$P:&FUJ'
MB47OT%^D@;?O\)_),F>#-PD`N8\!1V.3!R(BA19TMG#V9%9IMFEU86_0_Y=6
MA>_0C_FFA2J*%Q4``!,%!:'OX-_WJH5C"@40`[4)`._P#\@JC&,#!1!BA>_0
M[_6;"P4`C4=CV'<#$X7+_V*5EQ4``).%)9[OT#^(">V11V./^Q:;A[O_XI<#
MQP<`DP?P`F,&]Q:FA1<5```3!26`[^#_\5W-@T<%`,7/DX<'_<W+EQ4``).%
M!8@7!0``$P4%?N_@__GOT%^"*HA:AU:&4H67&```DXB(IY<'``"3AP=VEQ8`
M`).&!IJ)1>_0_Y?]5,5)EQL``).+:Z45J._0S^X<06.=-P/OT"_^!20JB%[@
MHHA:AU:&4H67!P``DX<'<I<6``"3A@:7B47OT/^3DP4`'%*%[]!?A>,"E?Q:
MA>_0OX+2A1<%```3!<5L[^`_\5*%[_`?M1)\S;L#O`D`[;UBA8%%[]!?EZJ$
M.='O\+^AJHGC3P7RDP5E_P%&)H7OT*_\#!`FA1E&[]`?B9E'8QWU"`)7MT=!
M0Y.'!S#C&O?P`U=!`I%GDX>'5.,3]_"3A>G\`48FA>_0+_D@`2:%HH43!H`"
M[]!?A9,'@`)C'O4$(HA6AI<8``"3B$B7EP<``).'QV5:AY<6``"3AJ:(B452
MA2,(`0KOT#^'B;>#N8D`XXH)Z$Z%[]`OVXU'X_2GZ'$53I67%0``DX5%A._0
MS^WC&@7F3HR]M1<5```3!86#9N[O\-^08O)F[N_0_XC2XE;^6OI>]F+R9N[O
MT/^'.7$B^!=D```#-.1L3NP&_";T4NBS!T0`A&.7:0``@[D):4P`@\<$"Q<%
M```3!25@`[<)`#KD`4>CB/0*[^`_TQG%`T<%`),'$`-C`/<2[_`OS;,'1`"$
M8R:%C48%1I<%``"3A<5_[]!/UZJ$'<$<:3,'1``(8XQC%P8``!,&IG[OT*_6
MG&B,8]Q%$Y>7`F-*!PZS!T0`B&.-1@5&EP4``).%Y7SOT&_3JH07:@``$PJ*
M:PW!3``7!0``$P7%4>_@'\N<:"J&C&-5Q;,'1`"(8^_0K]&S!T0`A&,%1I<%
M``"3A65Y)H7OT$_%JH47!@``$P;F>2:%[]!/SQ*4'&!,`!<%```3!25,HX@'
M"N_@/\8C.*H`*H0=R9,%`!PBA>_0S^$;!Q4`A4=C]><`DP?U_KGO(F>#MPD`
MN8\!1ZWGXG!"=*)TXFE":B%A@H`#-8H`[_`?G",XJ@`JA%W]%P4``!,%97-*
M\._03^2#1Q4`XX4'[O&]@S>*`"Z%C&/OX#^SD;^S!T0`B&/OT"_?&;=*\(,W
MB@"JAB*&C&,7!0``$P4%<N_0C^!*\._0+^TY<2+X)O0&_!=D```#-&1/JH1,
M"!<%```3!:5('&`^[(%'[^`?NAG-@T<%`!.'!_T3-Q<`D[<7`-F/B>>!Q(/'
M!`"9ZV)G'&"YCP%'J>OB<$)THG0A88*`)H7O\,^CDP7P`BKD[]"OUZ)G&<&3
M!Q4`/H7OT,_3$4:7!0``DX5E4N_0[Z]A\6)G'&"YCP%'@>M"=.)P)H6B="%A
M;^#?W>_0#^-!$1,%``@&Y._03[*710``@[6%1#=W74RW=^EA!@<W)D5GMU8R
M$(8'$P?GSQ,&%C"3AF9'DX<''QCI(S0%`B,X!0(C+`4&$.$,Y13M'/&B8$$!
M@H!=<2;\2OA2\%;LAN2BX$[T&'63%S8`,HFZEQ!Y@A>!DS.WYP"JA)-6V0$H
M73J6,X?&`)STF/BNBA.*A`,U[9,'\`-CVR<%FUEI`%KH&XOY_U[DF@F3&PL"
MD]L+`M:95H2BA1,&``12A>_0#[@3!`0$)H7OT,_[XQ4T_SL+8$$;&VL`&PD)
M_).7:P`["2L!HFM":Y.*"@2^FM:%4H5*AN_0K[0CK"0'IF`&9.)T0GFB>0)Z
MXFIA88*`DP<`!(F?/H1C2?D"FPD$`!.*A`-.AE*5UH7OT&^QO%P3!P`$H9^\
MW..3Y_PFA3L)B4#.FN_0+_2YMTJ$P;]=<:+@)OQ2\%;LAN1*^$[T`[F%`H/6
MA0(#UP4#DU<Y`"Z$D_?W`Y.%A0,SAO4`$P@`^!/:A@"36H<`@SD$`X4G(P`&
M`9N6A@`;%X<`$P:``ZJ$-IHSA?4`NIIC5?80$P<`!+L']T`11V/_YQ`)1V/S
MYQ!CG@<.(H4NY._0[^LB91,&@`.!1>_0S[N35XD!$]>)`1-9"0&3V0D!(QE4
M!R,;1`>C"#0'(PKT!J,*)`<BA2,(Y`;OT$_H'&`BA>&#(X#T`!Q@P8.C@/0`
M'&"A@R.!]``<8*.!]``<9.&#(X+T`!QDP8.C@O0`'&2A@R.#]``<9*.#]``<
M:.&#(X3T`!QHP8.CA/0`'&BA@R.%]``<:*.%]``<;.&#(X;T`!QLP8.CAO0`
M'&RA@R.']``<;*.']``<<.&#(XCT`!QPP8.CB/0`''"A@R.)]``<<*.)]``&
M9*9@XG1">:)Y`GKB:F%A;]`OHAV>@47OT*^M.;\C``4`$;<C``4`HP`%`/D7
M.I7CBP?N[;<C``4`HP`%`",!!0"C`04`\1<ZE0E'X^OG[-&_EV8``(.V!AUO
MT(^.``````$``@``````+W!R;V,O<V5L9B]E>&4``"5S+R5S````1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/
M5`````!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0
M``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E
M<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%
M4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%
M04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?
M1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!0
M05)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X``````````#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D
M``````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%5315(`````
M55-%4DY!344``````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@````!S
M:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,```
M``````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V-````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```````````M90```````"TM````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I
M.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F
M9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE
M(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN
M9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`]
M(#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P
M;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@
M("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW
M:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF
M("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*
M<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E
M='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P
M;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N
M9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F
M(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B
M*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@
M9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM
M>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F
M<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\[
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5]
M(#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP
M(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M
M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@
M)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F
M;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T
M(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L
M;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&
M24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC
M;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H
M(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A
M8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?
M;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L*
M*"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T
M:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#
M3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E
M;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@
M)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N
M86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H
M92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*
M?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E
M;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B
M)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI
M;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@!435!$25(``%1%35!$25(`5$5-4`````!435```````(FKS>\`
M````<&5R;'AS:2YC``````````!#04-(10```1L#.^P````<````V)'___@%
M``!8D___!`$```Z4__\8`0``[*7__V0!``"LIO__G`$``$ZG___X`0``!JG_
M_RP"``!@J?__6`(``'BJ__^H`@``TJK__\P"``#ZJO__X`(``+RK__\8`P``
MOJO__RP#``!>K?__=`,``("M__^4`P``7J[__\P#``#>L?___`,``"ZR__\@
M!```=K+__S@$``!\L___@`0``)*S__^<!```3K3__^`$```^N?__?`4``.JZ
M___`!0``C+O__R@&``#@N___2`8``-:\__^,!@``>+[__\@&````````$```
M```````#>E(``7P!`1L,`@`0````&````$R2__\B``````<!`$@````L````
M[I+__]X1````1`[P!6R7$H$"B`2)!I((DPJ4#)4.EA"8%)D6`WP1"L%$R$3)
M1-)$TT341-5$UD371-A$V40.`$(+```T````>````("D___``````$(.4%`.
MT""!`H@$B0:2"),*`G(*#E!"P4+(0LE"TD+30@X`0@L``%@```"P````"*7_
M_Z(`````0@Y`3H$"B`25#DZ2"%B)!I,*E`R6$&K)0M)"TT+40M9"P43(0M5"
M#@!"#D"!`H@$D@B5#E:)!I,*E`R6$%#)TM/4UD22"$+2````,`````P!``!.
MI?__N`$```!"#F!,B`2)!I((@0*3"I0,`N@*P4+(0LE"TD+30M1"#@!""R@`
M``!``0``TJ;__UH`````0@ZP`4:(!(D&@0("1@K!0LA"R4(.`$(+````3```
M`&P!````I___&`$```!"#M`!1)((@0)8B`1&R%#!0M)"#@!"#M`!@0*(!)((
M0HD&`DR3"@)@TU0*R$+)0@M&DPI(R,G31H@$B0:3"@`@````O`$``,BG__]:
M`````$(.$$*(!$J!`FC(0L%>#@`````0````X`$``/ZG__\H`````````#0`
M``#T`0``$JC__\(`````0@Y03@[0(($"B`2)!I((2`[00`*8"@Y00L%"R$+)
M0M)$#@!""P``$````"P"``"<J/__`@````````!$````0`(``(JH__^@`0``
M`$(.X`%8#N`A@0*(!(D&D@B3"I0,E0Z6$)<2`F8*#N`!0L%"R$+)0M)"TT+4
M0M5"UD+70@X`0@L<````B`(``.*I__\B`````$(.$$B(!($"4,A"P4(.`#0`
M``"H`@``Y*G__]X`````0@XP2@ZP(($"B`0"E`H.,$+!0LA"#@!""U8*#C!"
MP4+(2@X`1`L`+````.`"``"*JO__@`,```!"#C!(B`2)!I((@0(#-@,*R$+!
M0LE"TE(.`$0+````(````!`#``#:K?__4`````!"#B!$B`2!`@)`"L%"R$(.
M`$(+%````#0#```&KO__2`````!"#F!"@1(`1````$P#```VKO__!@$```!"
M#E!6#`6`@`2!`H@$B0:2"),*E`R5#I803@T"`J0*#E!"P4+(0LE"TD+30M1"
MU4+60@X`0@L`&````)0#``#TKO__%@````!"#A!"@0).P4(.`$````"P`P``
M[J[__[P`````0@Y`1H@$B0:!`@(\"LA"P4+)0@X`1`M&D@@"2,A"P4+)1-)*
M#@!$#D"!`H@$B09"D@@`F````/0#``!FK___\`0```!.#O`"7HD&D@B3"H$"
MB`0";I0,E0Z6$)<2`V(!"L%"R$+50M9"UT+)0M)"TT340@X`0@L"<I@41MAB
MU-76UU;(0L%"R4+20M-"#@!$#O`"@0*(!(D&D@B3"I0,E0Z6$)<2F!0#*@$*
MV$(+`MB9%D38V428%)D61-35UM?8V4R4#)4.EA"7$I@4F18`0````)`$``"Z
ML___K`$```!"#D!"B`14DPJ!`HD&E`P#*`$*P4+(0LE"TT+40@X`0@M:"I((
M1`L".`J2"$0+0I((```T````U`0``"*U__^B`````$(.0$:(!(D&@0("2`K!
M0LA"R4(.`$(+`CH*R$+!1,E"#@!$"P```"P````,!0``V(O__X`!````0@Y0
M2($"B0:(!)((`PP!"L%"R$+)1-)"#@!""P```!P````\!0``7+7__U0`````
M0@X01H$"`DC!0@X`````0````%P%``"0M?__]@````!"#E!4B0:2")0,E0Z!
M`H@$DPIVEA!&EQ("/M="UE8*P4+(0LE"TD+30M1"U4(.`$(+```X````H`4`
M`$*V__^B`0```$(.4$Z(!(D&E`R5#H$"D@B3"@-"`0K(0L%"R4+20M-"U$+5
M0@X`1`L````0````W`4``*BW__\,````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````!
M`````````/D"`````````0`````````$`P````````$`````````#@,`````
M```=`````````+@$````````(`````````!XJP```````"$`````````"```
M```````9`````````("K````````&P`````````(`````````!H`````````
MB*L````````<``````````@`````````!`````````#8`@```````/7^_V\`
M````^`4````````%`````````&`0````````!@````````#H!@````````H`
M````````[@0````````+`````````!@`````````%0``````````````````
M``,`````````P*T````````"`````````%@%````````%``````````'````
M`````!<`````````B!@````````'`````````'@6````````"`````````!H
M!P````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/[__V\`````&!8```````#___]O``````(`````````\/__
M;P````!.%0```````/G__V\`````"P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/__________``````````#@'0```````.`=
M````````X!T```````#@'0```````.`=````````X!T```````#@'0``````
M`.`=````````X!T```````#@'0```````.`=````````X!T```````#@'0``
M`````.`=````````X!T```````#@'0```````.`=````````X!T```````#@
M'0```````.`=````````X!T```````#@'0```````.`=````````X!T`````
M``#@'0```````.`=````````X!T```````#@'0```````.`=````````X!T`
M``````#@'0```````.`=````````X!T```````#@'0```````.`=````````
MX!T```````#@'0```````.`=````````X!T```````#@'0```````.`=````
M````X!T```````#@'0```````.`=````````X!T```````#@'0```````.`=
M````````X!T```````#@'0```````.`=````````X!T```````#@'0``````
M`.`=````````X!T```````#@'0```````.`=````````X!T```````"0JP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H4U5312!,:6YU>"D@,34N,2XQ(#(P,C4P-C(V`$%S````<FES8W8`
M`6D````$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC
M<W(R<#!?>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C,7`P
M7WIC83%P,%]Z8V0Q<#```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I<V-V+F%T=')I8G5T97,`
M````````````````````````````````````````````````````````````
M``````````````````````````````L````!`````@````````!P`@``````
M`'`"````````(0````````````````````$````````````````````3````
M!P````(`````````E`(```````"4`@```````"`````````````````````$
M````````````````````(0````<````"`````````+0"````````M`(`````
M```D````````````````````!````````````````````#@````%`````@``
M``````#8`@```````-@"````````(`,````````&``````````@`````````
M!``````````T````]O__;P(`````````^`4```````#X!0```````.P`````
M````!@`````````(````````````````````/@````L````"`````````.@&
M````````Z`8```````!X"0````````<````"````"``````````8````````
M`$8````#`````@````````!@$````````&`0````````[@0`````````````
M``````$```````````````````!.````____;P(`````````3A4```````!.
M%0```````,H`````````!@`````````"``````````(`````````6P```/[_
M_V\"`````````!@6````````&!8```````!@``````````<````"````"```
M`````````````````&H````$`````@````````!X%@```````'@6````````
M$`(````````&``````````@`````````&`````````!T````!````$(`````
M````B!@```````"(&````````%@%````````!@```!4````(`````````!@`
M````````>0````$````&`````````.`=````````X!T```````"P`P``````
M````````````$``````````0`````````'X````!````!@````````"0(0``
M`````)`A````````K"P```````````````````0```````````````````"$
M`````0````(`````````0$X```````!`3@```````'=!````````````````
M```(````````````````````C`````$````"`````````+B/````````N(\`
M``````#L````````````````````!````````````````````)H````!````
M`@````````"HD````````*B0````````\`4```````````````````@`````
M``````````````"D````$`````,`````````>*L```````!XFP````````@`
M```````````````````(``````````@`````````LP````X````#````````
M`("K````````@)L````````(````````````````````"``````````(````
M`````+\````/`````P````````"(JP```````(B;````````"```````````
M``````````@`````````"`````````#+````!@````,`````````D*L`````
M``"0FP```````#`"````````!P`````````(`````````!``````````U```
M``$````#`````````,"M````````P)T```````!``@``````````````````
M"``````````(`````````-D````!`````P``````````L`````````"@````
M````4`````````````````````@```````````````````#?````"`````,`
M````````4+````````!0H````````"@````````````````````(````````
M````````````Y`````$````P````````````````````4*`````````B````
M`````````````````0`````````!`````````.T````#``!P````````````
M`````````'*@````````=`````````````````````$`````````````````
M```!`````P````````````````````````#FH````````/\`````````````
5```````!````````````````````
